@@ -1,4 +1,5 @@
 /*  Glimmer - about.c
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -17,16 +18,19 @@
 #include "declarations.h"
 #include "about.h"
 
-void do_about(GtkWidget *widget, gpointer data)
+void
+do_about (GtkWidget * widget, gpointer data)
 {
-   GtkWidget *about_window;
-   const gchar *author[] = { "Chris Phelps <chicane@reninet.com>", NULL };
-   about_window = gnome_about_new(PACKAGE, "v" VERSION,
-                                  "Copyright 1999-2000 by Chris Phelps", author,
-                                  "Report bugs/crash problems to chicane@reninet.com\n"
-                                  URL_WEB "\n\n"
-                                  PACKAGE " is a versatile editing environment\n"
-                                  "for nearly any type of code.",
-                                  "glimmer-title.png");
-   gtk_widget_show(about_window);
+    GtkWidget *about_window;
+    const gchar *author[] = { "Chris Phelps <chicane@reninet.com>", NULL };
+
+    about_window = gnome_about_new (PACKAGE, "v" VERSION,
+                                    "Copyright 1999-2000 by Chris Phelps",
+                                    author,
+                                    "Report bugs/crash problems to chicane@reninet.com\n"
+                                    URL_WEB "\n\n" PACKAGE
+                                    " is a versatile editing environment\n"
+                                    "for nearly any type of code.",
+                                    "glimmer-title.png");
+    gtk_widget_show (about_window);
 }
