@@ -1,4 +1,5 @@
 /*  Glimmer - colors.h
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -21,8 +22,7 @@
 extern "C" {
 #endif
 
-static char *editor_color_names[] =
-{
+static char *editor_color_names[] = {
    "string",
    "char",
    "char_string",
