@@ -1,4 +1,5 @@
 /*  Glimmer - getprefs.h
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -34,6 +35,9 @@ void save_colors(void);
 void save_default_colors(void);
 void build_default_colors(void);
 
+void save_directory_history(GList *history, gchar *name);
+void get_directory_history(GList **history, gchar *name);
+
 #ifdef __cplusplus
 }
 #endif
