@@ -1,4 +1,5 @@
-/*  Glimmer - session.c
+/*  Glimmer - session.h
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -33,6 +34,8 @@ void save_session_as_continue(GtkWidget *widget, GnomeFileSelector *file_list);
 void save_session_as_error_continue(GtkWidget *widget, gchar *filename);
 gboolean save_session_to_file(gchar *filename);
 guint open_session_from_file(gchar *filename);
+void save_session_directory_history(void);
+void load_session_directory_history(void);
 
 extern gchar *session_file;
 
