@@ -1,4 +1,5 @@
 /*  Glimmer - splash.h
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -24,15 +25,14 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-typedef struct _SplashScreen
-{
-   GtkWidget *window;
-   GtkWidget *pixmap;
-   GtkWidget *pixmap_box;
-   GList *pixmaps;
-   gint index;
-   GtkWidget *auth_info;
-   GtkWidget *init_info;
+typedef struct _SplashScreen {
+    GtkWidget *window;
+    GtkWidget *pixmap;
+    GtkWidget *pixmap_box;
+    GList *pixmaps;
+    gint index;
+    GtkWidget *auth_info;
+    GtkWidget *init_info;
 }SplashScreen;
 
 SplashScreen *splash_screen_build(gchar *auth_info, gchar *pixmap);
