@@ -1,4 +1,5 @@
 /*  Glimmer - toolbar.h
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -14,8 +15,8 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef TOOLBAR_H
-#define TOOLBAR_H
+#ifndef _TOOLBAR_H_
+#define _TOOLBAR_H_
 
 #ifdef __cplusplus
 extern "C" {
