@@ -1,4 +1,5 @@
 /*  Glimmer - gdsmanpage.h
+ *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -20,8 +21,9 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#ifndef GDS_MANPAGE_H__
-#define GDS_MANPAGE_H__
+#ifndef _GDS_MANPAGE_H_
+#define _GDS_MANPAGE_H_
+
 #ifdef __cplusplus
 extern "C" {
 #endif
