@@ -1,4 +1,5 @@
 /*  Glimmer - gdstearaway.h
+ *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -17,8 +18,8 @@
 #include <stdio.h>
 #include <string.h>
 
-#ifndef GDS_TEAR_AWAY_H__
-#define GDS_TEAR_AWAY_H__
+#ifndef _GDS_TEAR_AWAY_H_
+#define _GDS_TEAR_AWAY_H_
 #ifdef __cplusplus
 extern "C" {
 #endif
