@@ -1,4 +1,5 @@
 /*  Glimmer - gnome-settings.h
+ *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -17,8 +18,10 @@
 #include <stdio.h>
 #include <string.h>
 #include <gnome.h>
-#ifndef GNOME_SETTINGS_H__
-#define GNOME_SETTINGS_H__
+
+#ifndef _GNOME_SETTINGS_H_
+#define _GNOME_SETTINGS_H_
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -32,27 +35,29 @@ extern "C" {
 typedef struct _GnomeSettings GnomeSettings;
 typedef struct _GnomeSettingsClass GnomeSettingsClass;
 
-struct _GnomeSettings
-{
-   GtkHPaned paned;
-   GtkWidget *ctree;
-   GtkWidget *hbox;
-   GList *children;
-   GtkWidget *current;
-   gint selected_row;
+struct _GnomeSettings {
+    GtkHPaned paned;
+    GtkWidget *ctree;
+    GtkWidget *hbox;
+    GList *children;
+    GtkWidget *current;
+    gint selected_row;
 };
 
-struct _GnomeSettingsClass
-{
-   GtkHPanedClass parent_class;
+struct _GnomeSettingsClass {
+    GtkHPanedClass parent_class;
 };
 
 GtkType gnome_settings_get_type(void);
 
 GtkWidget *gnome_settings_new(void);
-GtkCTreeNode *gnome_settings_add_page(GnomeSettings *settings, GtkCTreeNode *parent, gchar *title, GnomePixmap *pixmap, GtkWidget *new_child);
+
+GtkCTreeNode *gnome_settings_add_page(GnomeSettings *settings, GtkCTreeNode *parent,
+                                      gchar *title, GnomePixmap *pixmap,
+                                      GtkWidget *new_child);
 
 #ifdef __cplusplus /* cpp compatibility */
 }
 #endif
+
 #endif
