@@ -1,4 +1,5 @@
 /*  Glimmer - gnomeasciilist.h
+ *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -17,8 +18,8 @@
 #include <gnome.h>
 #include <stdio.h>
 
-#ifndef GNOME_ASCII_LIST_H__
-#define GNOME_ASCII_LIST_H__
+#ifndef _GNOME_ASCII_LIST_H_
+#define _GNOME_ASCII_LIST_H_
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -33,17 +34,17 @@ typedef struct _GnomeAsciiList GnomeAsciiList;
 typedef struct _GnomeAsciiListClass GnomeAsciiListClass;
 
 struct _GnomeAsciiList {
-   GtkWindow window;
-   GtkWidget *chars;
-   GtkWidget *vbox;
-   GtkWidget *entry;
-   GtkWidget *insert_button;
-   GtkWidget *close_button;
-   gint selected_row;
+    GtkWindow window;
+    GtkWidget *chars;
+    GtkWidget *vbox;
+    GtkWidget *entry;
+    GtkWidget *insert_button;
+    GtkWidget *close_button;
+    gint selected_row;
 };
 
 struct _GnomeAsciiListClass {
-   GtkWindowClass parent_class;
+    GtkWindowClass parent_class;
 };
 
 GtkType gnome_ascii_list_get_type(void);
