@@ -1,4 +1,5 @@
 /*  Glimmer - gnomedirentry.h
+ *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -20,8 +21,9 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#ifndef GNOME_DIRENTRY_H__
-#define GNOME_DIRENTRY_H__
+#ifndef _GNOME_DIRENTRY_H_
+#define _GNOME_DIRENTRY_H_
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -36,14 +38,14 @@ typedef struct _GnomeDirEntry GnomeDirEntry;
 typedef struct _GnomeDirEntryClass GnomeDirEntryClass;
 
 struct _GnomeDirEntry {
-   GtkHBox box;
-   GtkWidget *entry;
-   GtkWidget *chdir_button;
-   GtkWidget *dir_list;
+    GtkHBox box;
+    GtkWidget *entry;
+    GtkWidget *chdir_button;
+    GtkWidget *dir_list;
 };
 
 struct _GnomeDirEntryClass {
-   GtkHBoxClass parent_class;
+    GtkHBoxClass parent_class;
 };
 
 GtkType gnome_direntry_get_type(void);
@@ -58,4 +60,5 @@ void gnome_direntry_set_dir(GnomeDirEntry *dir_entry, const gchar *dir);
 #ifdef __cplusplus /* cpp compatibility */
 }
 #endif
+
 #endif
