@@ -1,4 +1,5 @@
 /*  Glimmer - gnomedirlist.h
+ *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -20,8 +21,9 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#ifndef GNOME_DIRLIST_H__
-#define GNOME_DIRLIST_H__
+#ifndef _GNOME_DIRLIST_H_
+#define _GNOME_DIRLIST_H_
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -36,19 +38,19 @@ typedef struct _GnomeDirList GnomeDirList;
 typedef struct _GnomeDirListClass GnomeDirListClass;
 
 struct _GnomeDirList {
-   GtkWindow window;
-   GtkWidget *dirs;
-   GtkWidget *entry;
-   GtkWidget *ok_button;
-   GtkWidget *cancel_button;
-   gchar *path;
-   gint selected_row;
-   GnomePixmap *folder_closed;
-   GnomePixmap *folder_open;
+    GtkWindow window;
+    GtkWidget *dirs;
+    GtkWidget *entry;
+    GtkWidget *ok_button;
+    GtkWidget *cancel_button;
+    gchar *path;
+    gint selected_row;
+    GnomePixmap *folder_closed;
+    GnomePixmap *folder_open;
 };
 
 struct _GnomeDirListClass {
-   GtkWindowClass parent_class;
+    GtkWindowClass parent_class;
 };
 
 GtkType gnome_dirlist_get_type(void);
